%% Spinsystem Parameters

SpinSys.S = 1/2;															% S quantum number
SpinSys.I = 1/2;															% I quantum number
SpinSys.g = [2.0034 2.0031 2.0027];											% g tensor
SpinSys.A = 0 + 5*[1 1 -2];													% Hyperfine values [MHz]
SpinSys.EulerA = [45 45 45];												% Euler angles {deg}

SpinSys.lwEPR = 0.5;														% Linewidth given in [MHz]
SpinSys.lwDNP = 0.5;														% Linewidth given in [MHz]

%% Simulation parameters

% SymParameters = 'QEPR';														% Select case
SymParameters = 'QSCtp1';														% Select case

switch SymParameters
%% Q-Band EPR Spectrum no DNP
	case {'QEPR'}

		Opt.SC = 'y';														% Single crystal simulation (y/n)
		Opt.CalcEPR = 'y';													% Simulate EPR? (y/n)
		Opt.CalcDNP = 'n';													% Simulate DNP? (y/n)
		Opt.Save = 'y';
		Opt.SaveFileName = 'QEPR';											% Filename for parameters to save
		Opt.Threshold = 1e14;
		
		Out.OutputScaling = 100;											% Scaling factor for plotting forbidden transitions
		
		Par.phi = 0;														% Single crystal angle phi
		Par.theta = 0;														% Single crystal angle theta
		Par.SphereSlices = 30;												% Number of slices on unit sphere
		Par.Sym = 'C2h';
		
		Par.CF = 1248.3;													% Center field [mT]
		Par.SW = 5;															% Sweep Width [mT]
		Par.BnPts = 1001;													% Resolution field vector
		Par.vMW = 34.996455;												% Microwave frequency [GHz]
		Par.B1 = 5;															% B1 field in [MHz]
		Par.tp = 10;														% Polarization time in [us] [start end]
		Par.tnPts = 1;														% Resolutio microwave increments

%% Q-Band EPR and DNP enhancement profile, single-crystal
	case {'QSC'}

		Opt.SC = 'y';														% Single crystal simulation (y/n)
		Opt.CalcEPR = 'y';													% Simulate EPR? (y/n)
		Opt.CalcDNP = 'y';													% Simulate DNP? (y/n)
		Opt.Save = 'y';
		Opt.SaveFileName = 'QSC';											% Filename for parameters to save
		Opt.Threshold = 1e14;
		
		Out.OutputScaling = 5000;											% Scaling factor for plotting forbidden transitions
		
		Par.phi = 0;														% Single crystal angle phi
		Par.theta = 0;														% Single crystal angle theta
		Par.SphereSlices = 30;												% Number of slices on unit sphere
		Par.Sym = 'C2h';
		
		Par.CF = 1248.3;													% Center field [mT]
		Par.SW = 5;															% Sweep Width [mT]
		Par.BnPts = 1001;													% Resolution field vector
		Par.vMW = 34.996455;												% Microwave frequency [GHz]
		Par.B1 = 5;															% B1 field in [MHz]
		Par.tp = 10;														% Polarization time in [us] [start end]
		Par.tnPts = 1;														% Resolutio microwave increments
		
%% Q-Band EPR and DNP enhancement profile, single-crystal, time evolution
%% 1D
	case {'QSCtp1'}

		Opt.SC = 'y';														% Single crystal simulation (y/n)
		Opt.CalcEPR = 'y';													% Simulate EPR? (y/n)
		Opt.CalcDNP = 'y';													% Simulate DNP? (y/n)
		Opt.Save = 'y';
		Opt.SaveFileName = 'QSCtp1';										% Filename for parameters to save
		Opt.Threshold = 1e14;
		
		Out.OutputScaling = 5000;											% Scaling factor for plotting forbidden transitions
		
		Par.phi = 0;														% Single crystal angle phi
		Par.theta = 0;														% Single crystal angle theta
		Par.SphereSlices = 20;												% Number of slices on unit sphere
		Par.Sym = 'C2h';
		
% 		Par.CF = 1250.419;			% DQ									% Center field [mT] (on-resonant)
		Par.CF = 1246.63318;		% ZQ									% Center field [mT] (on-resonant)

		Par.SW = 5;															% Sweep Width [mT]
		Par.BnPts = 1;														% Resolution field vector
		Par.vMW = 34.996455;												% Microwave frequency [GHz]
		Par.B1 = 5;															% B1 field in [MHz]
		Par.tp = [0 5];														% Polarization time in [us] [start end]
		Par.tnPts = 100;													% Resolutio microwave increments
	
%% Q-Band EPR and DNP enhancement profile, single-crystal, time evolution
%% 2D
	case {'QSCtp'}

		Opt.SC = 'y';														% Single crystal simulation (y/n)
		Opt.CalcEPR = 'y';													% Simulate EPR? (y/n)
		Opt.CalcDNP = 'y';													% Simulate DNP? (y/n)
		Opt.Save = 'y';
		Opt.SaveFileName = 'QSCtp';											% Filename for parameters to save
		Opt.Threshold = 1e14;
		
		Out.OutputScaling = 5000;											% Scaling factor for plotting forbidden transitions
		
		Par.phi = 0;														% Single crystal angle phi
		Par.theta = 0;														% Single crystal angle theta
		Par.SphereSlices = 30;												% Number of slices on unit sphere
		Par.Sym = 'C2h';
		
		Par.CF = 1248.3;													% Center field [mT]
		Par.SW = 5;															% Sweep Width [mT]
		Par.BnPts = 1001;													% Resolution field vector
		Par.vMW = 34.996455;												% Microwave frequency [GHz]
		Par.B1 = 5;															% B1 field in [MHz]
		Par.tp = [1 15];													% Polarization time in [us] [start end]
		Par.tnPts = 100;													% Resolutio microwave increments

%% Q-Band EPR and DNP enhancement profile, powder, time evolution
	case {'QP'}
		Opt.SC = 'n';														% Single crystal simulation (y/n)
		Opt.CalcEPR = 'y';													% Simulate EPR? (y/n)
		Opt.CalcDNP = 'y';													% Simulate DNP? (y/n)
		Opt.Save = 'y';
		Opt.SaveFileName = 'QP_20';											% Filename for parameters to save
		Opt.Threshold = 1e14;
		
		Out.OutputScaling = 5000;											% Scaling factor for plotting forbidden transitions
		
		Par.phi = 0;														% Single crystal angle phi
		Par.theta = 0;														% Single crystal angle theta
		Par.SphereSlices = 20;												% Number of slices on unit sphere
		Par.Sym = 'C2h';

		Par.CF = 1248.3;													% Center field [mT]
		Par.SW = 5;															% Sweep Width [mT]
		Par.BnPts = 1001;													% Resolution field vector
		Par.vMW = 34.996455;												% Microwave frequency [GHz]
		Par.B1 = 5;															% B1 field in [MHz]
		Par.tp = 5;															% Polarization time in [us] [start end]
		Par.tnPts = 1;														% Resolutio microwave increments

%% Q-Band EPR and DNP enhancement profile, powder, differential SE
	case {'QPB'}
		SpinSys.g = [2.0055 2.003 2.0005];									% g tensor
		SpinSys.lwEPR = 2;													% Linewidth given in [MHz]
		SpinSys.lwDNP = 2;													% Linewidth given in [MHz]
		Opt.SC = 'n';														% Single crystal simulation (y/n)
		Opt.CalcEPR = 'y';													% Simulate EPR? (y/n)
		Opt.CalcDNP = 'y';													% Simulate DNP? (y/n)
		Opt.Save = 'y';
		Opt.SaveFileName = 'QPB_50';										% Filename for parameters to save
		Opt.Threshold = 1e14;
		
		Out.OutputScaling = 50;											% Scaling factor for plotting forbidden transitions
		
		Par.phi = 0;														% Single crystal angle phi
		Par.theta = 0;														% Single crystal angle theta
		Par.SphereSlices = 20;												% Number of slices on unit sphere
		Par.Sym = 'C2h';

		Par.CF = 1248.3;													% Center field [mT]
		Par.SW = 10;															% Sweep Width [mT]
		Par.BnPts = 1001;													% Resolution field vector
		Par.vMW = 34.996455;												% Microwave frequency [GHz]
		Par.B1 = 5;															% B1 field in [MHz]
		Par.tp = 5;														% Polarization time in [us] [start end]
		Par.tnPts = 1;														% Resolutio microwave increments

%% D-Band EPR and DNP enhancement profile, powder
	case {'DP'}
		Opt.SC = 'n';														% Single crystal simulation (y/n)
		Opt.CalcEPR = 'y';													% Simulate EPR? (y/n)
		Opt.CalcDNP = 'n';													% Simulate DNP? (y/n)
		Opt.Save = 'y';
		Opt.SaveFileName = 'DP_!00';										% Filename for parameters to save
		Opt.Threshold = 1e14;
		
		Out.OutputScaling = 5000;											% Scaling factor for plotting forbidden transitions
		
		Par.phi = 0;														% Single crystal angle phi
		Par.theta = 0;														% Single crystal angle theta
		Par.SphereSlices = 100;												% Number of slices on unit sphere
		Par.Sym = 'C2h';

		Par.CF = 4975.7;													% Center field [mT]
		Par.SW = 20;														% Sweep Width [mT]
		Par.BnPts = 1001;													% Resolution field vector
		Par.vMW = 139.5;													% Microwave frequency [GHz]
		Par.B1 = 5;															% B1 field in [MHz]
		Par.tp = 5;															% Polarization time in [us] [start end]
		Par.tnPts = 1;														% Resolutio microwave increments

end
