tic																			% Start stop watch

disp('* ')
disp('* Calculating DNP enhancement profile')
disp('* ')

Sim.MSz = zeros(Par.tnPts,Par.BnPts);
Sim.MIz = zeros(Par.tnPts,Par.BnPts);

B = Sim.B;																	% Assign to non-structured variable (required for parfor)
vMW = Sim.vMW;																% Assign to non-structured variable (required for parfor)

thetanPts = length(Sim.theta);

%% Calculation of DNP enhancement

for k = 1:thetanPts															% Loop over crystalite orientations
	
	disp(['Orientation: ' num2str(k) ' out of ' num2str(thetanPts) ' Orientations'])
	
	R = RotMatPAS2ZAS([Sim.phi(k) Sim.theta(k) 0]);							% Rotation matrix to rotate into crystalite orientation
	
	gZAS = R*g/R;															% Rotate g tensor in ZAS
	AZAS = R*A/R;															% Rotate A tensor in ZAS
	gzz = gZAS(3,3);														% g tensor in high-field approximation
	
	HA = AZAS(3,1).*SpinOp.SzIx ...
		+ AZAS(3,2).*SpinOp.SzIy ...
		+ AZAS(3,3).*SpinOp.SzIz;											% Hyperfine tensor in pseud high-field approximation
	
	for m = 1:Par.tnPts														% Loop over microwave polarization time
		
		MSz = zeros(1,Par.BnPts);											% Preallocation
		MIz = zeros(1,Par.BnPts);											% Preallocation
		tp = Sim.tp(m);														% Preallocation
		
		for l = 1:Par.BnPts													% Loop over field positions
		
			HS = B(l)*Const.betae*10*SpinOp.Sz*gzz;							% Electron Zeeman Hamiltonian in lab frame
			H = HS + HI + HA + H1;											% Complete static Hamiltonian (H0)
			
			Hrot = H - SpinOp.Sz*vMW;										% Electron Zeeman Hamiltonian in rotating frame

			U = expm(-1i*2*pi*Hrot*tp);										% Microwave propagator
			rho = U*SpinOp.Sz/U;											% Propagate equilibrium density matrix

			rho = round(rho*Opt.Threshold)/Opt.Threshold;					% Blank small elements
				
			MSz(l) = real(trace(rho*SpinOp.Sz))/thetanPts;					% Calculate expectation value for Sz
			MIz(l) = real(trace(rho*SpinOp.Iz))/thetanPts;					% Calculate expectation value for Iz
			
		end
		
		Sim.MSz(m,:) = Sim.MSz(m,:) + MSz;									% Sum over crystallite orientations
		Sim.MIz(m,:) = Sim.MIz(m,:) + MIz;									% Sum over crystallite orientations

	end	
end

Sim.timeDNP = toc;															% Get time for simulation
disp(['* Computation time for DNP enhancement profile: ' num2str(Sim.timeDNP) ' s'])


%% Postprocessing of data

for m = 1:Par.tnPts															% Apply linewidth convolution for each tp point
	
	Sim.eDNP(m,:) = ConvoluteLw(Sim.B,Sim.MIz(m,:),Sim.lwDNP/Const.gammae/10);
	Sim.MSz(m,:) = ConvoluteLw(Sim.B,Sim.MSz(m,:),Sim.lwEPR/Const.gammae/10);
	
end

clear B vMW																	% Clean up workspace