% Calculation of the EPR spectrum. This routine is part of SimSE.m
% Thorsten Maly, January 2010

tic																			% Start stop watch

disp('* ')
disp('* Calculating EPR Spectrum')
disp('* ')

%% Calculate resonance frequencies and intensities

for k = 1:length(Sim.theta)													% Loop over crystalite orientations (powder average)

	R = RotMatPAS2ZAS([Sim.phi(k) Sim.theta(k) 0]);							% Rotation matrix to rotate tensor into crystalite orientation
	gZAS = R*g/R;															% Rotate g tensor in ZAS
	AZAS = R*A/R;															% Rotate A tensor in ZAS
	
	HA = AZAS(3,1).*SpinOp.SzIx ...
		+ AZAS(3,2).*SpinOp.SzIy ...
		+ AZAS(3,3).*SpinOp.SzIz;											% Hyperfine Hamiltonian in pseudo high-field approximation
		
	HS = Const.gammae*Sim.vMW/(Const.betae*gZAS(3,3)).*SpinOp.Sz;			% Electron Zeeman interaction in [Hz]
	H0 = HS + HI + HA;														% Complete Hamiltonian (H0)
	
	[V D] = eig(H0);														% Caculate Eigenvalues of H0
	
	D = diag(D);
	T = V\SpinOp.Sx*V;														% Rotate tranistion operator into diagonal frame of H0
	I = T.*conj(T);															% Calculate intensities
	I = round(I*Opt.Threshold)/Opt.Threshold;								% Blank small elements (rounding)
	
	Index = find(I~=0);														% Find non-zero elements
	[m,n] = ind2sub(size(I),Index);											% Convert to matrix indeces
	
	Sim.v(k,:) = (D(m) - D(n));												% Get transition frequencies
	Sim.I(k,:) = I(Index);													% Get transition intensities
	
end

%% Calculate spectrum

Sim.Bres = Sim.v(:)/Const.gammae/10;										% Resonance frequencies in [mT]
Sim.I = Sim.I(:);															% Reshape intensity vector

[Spec Sim.bin] = histc(Sim.Bres,Sim.B);										% Sort resonances

for l=1:length(Sim.B)														% Calculate intensities
	
	index = Sim.bin==l;
	Sim.Spectrum(l) = sum(Sim.I(index));									% Sum over intensities
	
end

Sim.SpecEPR = ConvoluteLw(Sim.B,Sim.Spectrum,Sim.lwEPR/Const.gammae/10);	% Convolute with lineshape function
Sim.SpecEPR = Sim.SpecEPR./max(Sim.SpecEPR);								% Normalize spectrum to max intensity
Sim.timeEPR = toc;															% Get time for simulation

disp(['* Computation time for EPR spectrum: ' num2str(Sim.timeEPR) ' s'])